@@ -23,20 +23,21 @@
 #include "rconfig.h"
 #include "rlog.h"
 
-#if defined(DEF_CAM_EXPERT) || defined(DEF_WINDOWS)
+#if defined(DEF_CAM_EXPERT)
 #include "rvalidate.h"
 #endif
 
 
 #include "rmath.h"
 
-int 
-main(int argc, char** argv) {
+int main(int argc, char** argv) {
 
   int ret;
 
   QApplication app(argc, argv);
 
+  RLOG("\nstart");
+
   // Read INI/QM-File:
   //
   QFileInfo prgInfo(argv[0]);
@@ -49,13 +50,13 @@ main(int argc, char** argv) {
   
   app.setFont( RCONFIG->getFont(0) );  // Set default font for application
 
-#if defined(DEF_CAM_EXPERT) || defined(DEF_WINDOWS)
+#if defined(DEF_CAM_EXPERT)
   RValidate v1;                       // Validate reg.txt (CAM Expert)
   if(!v1.validate()) exit(1);
 #endif
 
   RAppWin* appWin = RAppWin::getRAppWin();
-
+  
   // Set Application style:
   //
   QApplication::setStyle( new QWindowsStyle() );
@@ -67,7 +68,7 @@ main(int argc, char** argv) {
   appWin->init();
   appWin->show();
   appWin->zoomToPage();
-  
+
   // Show Intro:
   //
 #ifndef DEF_LESS_DIALOGS
@@ -118,7 +119,7 @@ main(int argc, char** argv) {
   }
   
   if(doExit) exit(0);
-
+  
   appWin->setFocus();
   appWin->resizeChildren();
   
