@@ -21,7 +21,7 @@
 #define DEF_CHOOSEMACH_WIDTH  360
 #define DEF_CHOOSEMACH_HEIGHT 120
 
-class RLabel;
+class QLabel;
 class RComboBox;
 
 class RChooseMach : public QDialog
@@ -44,7 +44,7 @@ private:
   QPushButton* bCancel;
   QPushButton* bHelp;
 
-  RLabel*      lText;
+  QLabel*      lText;
   RComboBox*   mbMachine;
 
   QPushButton* bNew;
