@@ -176,7 +176,7 @@ RConfig::ini()
   addSetting( "Print:PrintAdjustmentFactor", "1.0");
 
   addSetting( "Paths:BrowserPath", (RUNNING_WINDOWS ? "C:\\Progra~1\\Intern~1\\Iexplore.exe" : "netscape"));
-  addSetting( "Paths:LibraryPath1", "/usr/share/qcad/libraries" );
+  addSetting( "Paths:LibraryPath1", DATADIR "/" DEF_APPNAME_L "/libraries" );
 
   verbose=false;
 }
@@ -220,7 +220,7 @@ RConfig::createConfigFile( bool overwrite )
   // Show initial setup dialog if no config file exists:
   if(!configFile.exists()) {
     RInitialDialog dlg(0, "", true);
-    dlg.show();
+    dlg.exec();
   }
 
   if(!configFile.exists() || overwrite) {
@@ -404,7 +404,7 @@ RConfig::createLanguageList()
     newLanguage = new languageStruct;
     newLanguage->name = "English";
     newLanguage->sign = "en";
-    newLanguage->charset = QFont::Latin1;
+
     languageList.append(newLanguage);
     
     if (langFile.open(IO_ReadOnly)) {
@@ -421,7 +421,6 @@ RConfig::createLanguageList()
             newLanguage = new languageStruct;
             newLanguage->name = name;
             newLanguage->sign = sign;
-            newLanguage->charset = mtStringToCharset(charset);
 
             languageList.append(newLanguage);
         }
@@ -446,7 +445,7 @@ RConfig::readQmFile()
     
     // Search for language file
     QString qmPath;
-    qmPath = searchFile(QString("messages/qcad_") +
+    qmPath = fileSearchFile(QString("messages"), QString("qcad_") +
                         getSetting("Language:Language") + ".qm");
     if (qmPath.isEmpty()) {
         addSetting("Language:Language", "en");
@@ -458,8 +457,8 @@ RConfig::readQmFile()
 
     // Add charset for this language to the settings
     if (getSetting("Application:Charset").isEmpty()) {
-        addSetting("Application:Charset",
-                   mtCharsetToString(getLanguageCharset(getLanguageName(getSetting("Language:Language")))));
+      //addSetting("Application:Charset",
+      //           mtCharsetToString(getLanguageCharset(getLanguageName(getSetting("Language:Language")))));
     }
 
     // Ini fonts:
@@ -467,23 +466,23 @@ RConfig::readQmFile()
     font0 = new QFont( getSetting("Application:FontName"),
                        getSettingInt("Application:FontSize0"),
                        QFont::Normal,
-                       false,
-                       mtStringToCharset(getSetting("Application:Charset")) );
+                       false/*,
+			      mtStringToCharset(getSetting("Application:Charset"))*/ );
     font1 = new QFont( getSetting("Application:FontName"),
                        getSettingInt("Application:FontSize1"),
                        QFont::Normal,
-                       false,
-                       mtStringToCharset(getSetting("Application:Charset")) );
+                       false/*,
+			      mtStringToCharset(getSetting("Application:Charset"))*/ );
     font2 = new QFont( getSetting("Application:FontName"),
                        getSettingInt("Application:FontSize2"),
                        QFont::Normal,
-                       false,
-                       mtStringToCharset(getSetting("Application:Charset")) );
+                       false/*,
+			      mtStringToCharset(getSetting("Application:Charset"))*/ );
     font3 = new QFont( getSetting("Application:FontName"),
                        getSettingInt("Application:FontSize3"),
                        QFont::Normal,
-                       false,
-                       mtStringToCharset(getSetting("Application:Charset")) );
+                       false/*,
+			      mtStringToCharset(getSetting("Application:Charset"))*/ );
 
     return true;
 }
@@ -497,6 +496,7 @@ RConfig::readQmFile()
  * ~/.qcad/...         <BR>
  * /usr/share/qcad/... <BR>
  */
+/*
 QString
 RConfig::searchFile(const QString& _relPath)
 const
@@ -514,7 +514,7 @@ const
 
   // Search in /usr/share/qcad/... dir:
   if(!QFileInfo(path).exists()) {
-    path = QString("/usr/share/")+DEF_APPNAME_L+"/"+_relPath;
+	path = QString(DATADIR)+"/"+DEF_APPNAME_L+"/"+_relPath;
   }
 #endif
 
@@ -524,6 +524,7 @@ const
 
   return path;
 }
+*/
 
 
 /*! Gets the short two letter sign for a given language.
@@ -560,19 +561,6 @@ RConfig::getLanguageName( QString _languageSign )
 
 
 
-QFont::CharSet
-RConfig::getLanguageCharset( QString _languageName )
-{
-  languageStruct* ls;
-  for( ls=languageList.first(); ls!=0; ls=languageList.next() ) {
-    if( ls->name.lower()==_languageName.lower() ) {
-      return ls->charset;
-    }
-  }
-
-  return QFont::Latin1;
-}
-
 
 
 
