@@ -96,6 +96,7 @@ RFileDxf::readFromBuffer(bool add)
   RLayer*   currentLayer=0;         // Pointer to current layer
   QList<RGraphic> blockList;        // List of blocks
   blockList.setAutoDelete( true );
+  bool      oldColorNumbers=false;  // use old color numbers (qcad<1.5.3)
 
   if(!add) graphic->clearLayers();
 
@@ -128,7 +129,7 @@ RFileDxf::readFromBuffer(bool add)
 
       // $-Setting in the header of DXF found
       //
-      if( !!dxfLine &&
+      if( dxfLine &&
           dxfLine[0]=='$' ) {
 
         // Units:
@@ -336,8 +337,9 @@ RFileDxf::readFromBuffer(bool add)
           if(dxfCode=getBufLine()) {
             if( dxfCode.toInt()==10 ) {
               if( dxfLine=getBufLine() ) {
-                graphic->setMinGridX( dxfLine.toDouble() );
                 double gx=dxfLine.toDouble();
+                if (gx<0.0001) gx=0.0001;
+                graphic->setMinGridX(gx);
                 graphic->setGridFormat( Fractional );
 
                 for( double q=0.00000001; q<=100000.0; q*=10.0 ) {
@@ -352,7 +354,9 @@ RFileDxf::readFromBuffer(bool add)
           if(dxfCode=getBufLine()) {
             if( dxfCode.toInt()==20 ) {
               if( dxfLine=getBufLine() ) {
-                graphic->setMinGridY( dxfLine.toDouble() );
+                double gy=dxfLine.toDouble();
+                if (gy<0.0001) gy=0.0001;
+                graphic->setMinGridY(gy);
               }
             }
           }
@@ -412,7 +416,7 @@ RFileDxf::readFromBuffer(bool add)
 
       // Entity
       //
-      else if(!!dxfLine &&
+      else if(dxfLine &&
               dxfLine[0]>='A' && dxfLine[0]<='Z') {
          	
         if(dxfLine=="EOF") {
@@ -453,17 +457,22 @@ RFileDxf::readFromBuffer(bool add)
                     if(currentLayer) currentLayer->setWidth(dxfLine.toInt());
                     break;
                   case 62:  // Color
-                    if(currentLayer) currentLayer->setColor( graphic->numberToColor(dxfLine.toInt()) );
+				  	if (dxfLine.toInt()==0) {
+						oldColorNumbers=true;
+					}
+                    if(currentLayer) {
+						currentLayer->setColor( graphic->numberToColor(dxfLine.toInt(), !oldColorNumbers));
+					}
                     break;
                   default:
                     break;
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
           graphic->setStyle("CONTINOUS");
           graphic->setWidth(0);
-          graphic->setColor(0);
+          graphic->setColor(0, false);
         }
 
         // ------
@@ -479,10 +488,10 @@ RFileDxf::readFromBuffer(bool add)
           // Read block information until first entity:
           do {
             dxfCode=getBufLine();
-            if(!!dxfCode) code=dxfCode.toInt();
-            if(!!dxfCode && code!=0) {
+            if(dxfCode) code=dxfCode.toInt();
+            if(dxfCode && code!=0) {
               dxfLine=getBufLine();
-              if(!!dxfLine) {
+              if(dxfLine) {
                 switch(code) {
                   case  2:  // Block name
                     blockName = dxfLine;
@@ -504,10 +513,10 @@ RFileDxf::readFromBuffer(bool add)
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
 
           // proccess block:
-          if(!!dxfCode) {
+          if(dxfCode) {
             bool done=false;
             bool first=true;
 
@@ -523,19 +532,19 @@ RFileDxf::readFromBuffer(bool add)
               else {
                 dxfCode=getBufLine();
                 blockContents+=dxfCode+"\n";
-                if(!!dxfCode) code=dxfCode.toInt();
+                if(dxfCode) code=dxfCode.toInt();
               }
 
-              if(!!dxfCode) {
+              if(dxfCode) {
                 dxfLine=getBufLine();
                 if(code!=0 || dxfLine!="ENDBLK") blockContents+=dxfLine+"\n";
               }
 
-              if(!!dxfCode && code==0 && dxfLine=="ENDBLK") {
+              if(dxfCode && code==0 && dxfLine=="ENDBLK") {
                 done=true;
               }
 
-            }while(!!dxfCode && !done);
+            }while(dxfCode && !done);
 
             RGraphic* newBlock = new RGraphic( 0 );
             RFileDxf blockBuffer( blockName, newBlock );
@@ -592,14 +601,14 @@ RFileDxf::readFromBuffer(bool add)
           do {
             dxfCode=getBufLine();
 
-            if(!!dxfCode) code=dxfCode.toInt();
-            if(!!dxfCode && code!=0) {
+            if(dxfCode) code=dxfCode.toInt();
+            if(dxfCode && code!=0) {
               dxfLine=getBufLine();
 
               RLOG( "\ninsertLine: " );
               RLOG( dxfLine );
 
-              if(!!dxfLine) {
+              if(dxfLine) {
                 switch(code) {
                   case  2:  // Block name
                     blockName = dxfLine;
@@ -638,7 +647,7 @@ RFileDxf::readFromBuffer(bool add)
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
 
           // Search block:
 
@@ -710,14 +719,14 @@ RFileDxf::readFromBuffer(bool add)
                     graphic->setWidth(dxfLine.toInt());
                     break;
                   case 62:  // Color
-                    graphic->setColor(dxfLine.toInt());
+                    graphic->setColor(dxfLine.toInt(), !oldColorNumbers);
                     break;
                   default:
                     break;
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
           graphic->addPoint(vx1, vy1, currentLayerNum, add);
         }
         
@@ -764,14 +773,14 @@ RFileDxf::readFromBuffer(bool add)
                     graphic->setWidth(dxfLine.toInt());
                     break;
                   case 62:  // Color
-                    graphic->setColor(dxfLine.toInt());
+                    graphic->setColor(dxfLine.toInt(), !oldColorNumbers);
                     break;
                   default:
                     break;
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
           
           if(!mtCompFloat(vx1, vx2) || !mtCompFloat(vy1, vy2)) {
             graphic->addLine(vx1, vy1, vx2, vy2, currentLayerNum, add);
@@ -822,14 +831,14 @@ RFileDxf::readFromBuffer(bool add)
                     graphic->setWidth(dxfLine.toInt());
                     break;
                   case 62:  // Color
-                    graphic->setColor(dxfLine.toInt());
+                    graphic->setColor(dxfLine.toInt(), !oldColorNumbers);
                     break;
                   default:
                     break;
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
           if(vcr>0.0 && !mtCompFloat(va1, va2)) {
             graphic->addArc(vcx, vcy, vcr, va1, va2, false, currentLayerNum, add);
           }
@@ -871,14 +880,14 @@ RFileDxf::readFromBuffer(bool add)
                     graphic->setWidth(dxfLine.toInt());
                     break;
                   case 62:  // Color
-                    graphic->setColor(dxfLine.toInt());
+                    graphic->setColor(dxfLine.toInt(), !oldColorNumbers);
                     break;
                   default:
                     break;
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
           if(vcr>0.0) {
             graphic->addCircle(vcx, vcy, vcr, 0.0, 360.0, false, currentLayerNum, add);
           }
@@ -943,14 +952,14 @@ RFileDxf::readFromBuffer(bool add)
                     graphic->setWidth(dxfLine.toInt());
                     break;
                   case 62:  // Color
-                    graphic->setColor(dxfLine.toInt());
+                    graphic->setColor(dxfLine.toInt(), !oldColorNumbers);
                     break;
                   default:
                     break;
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
 
           // Create the ellipse as lines:
           //
@@ -1030,7 +1039,7 @@ RFileDxf::readFromBuffer(bool add)
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
 
           if(closed) ++ctrlPts;
 
@@ -1094,14 +1103,14 @@ RFileDxf::readFromBuffer(bool add)
                     graphic->setWidth(dxfLine.toInt());
                     break;
                   case 62:  // Color
-                    graphic->setColor(dxfLine.toInt());
+                    graphic->setColor(dxfLine.toInt(), !oldColorNumbers);
                     break;
                   default:
                     break;
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
 
           // Create the spline as lines:
           //
@@ -1219,14 +1228,14 @@ RFileDxf::readFromBuffer(bool add)
                     graphic->setWidth(dxfLine.toInt());
                     break;
                   case 62:  // Color
-                    graphic->setColor(dxfLine.toInt());
+                    graphic->setColor(dxfLine.toInt(), !oldColorNumbers);
                     break;
                   default:
                     break;
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
 
           // Close Polyline:
           //
@@ -1323,14 +1332,14 @@ RFileDxf::readFromBuffer(bool add)
                     graphic->setWidth(dxfLine.toInt());
                     break;
                   case 62:  // Color
-                    graphic->setColor(dxfLine.toInt());
+                    graphic->setColor(dxfLine.toInt(), !oldColorNumbers);
                     break;
                   default:
                     break;
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
 
           gotoBufLine("VERTEX");
           vab=0;
@@ -1370,14 +1379,14 @@ RFileDxf::readFromBuffer(bool add)
                     graphic->setWidth(dxfLine.toInt());
                     break;
                   case 62:  // Color
-                    graphic->setColor(dxfLine.toInt());
+                    graphic->setColor(dxfLine.toInt(), !oldColorNumbers);
                     break;
                   default:
                     break;
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
         }
 
         // --------------------
@@ -1422,14 +1431,14 @@ RFileDxf::readFromBuffer(bool add)
                     graphic->setWidth(dxfLine.toInt());
                     break;
                   case 62:  // Color
-                    graphic->setColor(dxfLine.toInt());
+                    graphic->setColor(dxfLine.toInt(), !oldColorNumbers);
                     break;
                   default:
                     break;
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
           //if(!mtCompFloat(ax, vx2) || !mtCompFloat(ay, vy2) || !mtCompFloat(vab, 0.0)) {
           // removed: 20000201: Doesn't work for polylines with very high resolution
             graphic->addPolylineElement(ax, ay,
@@ -1609,14 +1618,14 @@ RFileDxf::readFromBuffer(bool add)
                     graphic->setWidth(dxfLine.toInt());
                     break;
                   case 62:  // Color
-                    graphic->setColor(dxfLine.toInt());
+                    graphic->setColor(dxfLine.toInt(), !oldColorNumbers);
                     break;
                   default:
                     break;
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
           graphic->addText(vx1, vy1,
                            RFonts::getRFonts()->getFontNumber(vfont),
                            vtext,
@@ -1724,7 +1733,7 @@ RFileDxf::readFromBuffer(bool add)
                     graphic->setWidth(dxfLine.toInt());
                     break;
                   case 62:  // Color
-                    graphic->setColor(dxfLine.toInt());
+                    graphic->setColor(dxfLine.toInt(), !oldColorNumbers);
                     break;
 
                   default:
@@ -1732,7 +1741,7 @@ RFileDxf::readFromBuffer(bool add)
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
           double dist;
           RElement tmpEl;
 
@@ -1930,7 +1939,7 @@ RFileDxf::readFromBuffer(bool add)
                     graphic->setWidth(dxfLine.toInt());
                     break;
                   case 62:  // Color
-                    graphic->setColor(dxfLine.toInt());
+                    graphic->setColor(dxfLine.toInt(), !oldColorNumbers);
                     break;
                   case 91:  // Number of boundary paths (loops)
                     //numPaths=dxfLine.toInt();
@@ -1954,7 +1963,7 @@ RFileDxf::readFromBuffer(bool add)
                 }
               }
             }
-          }while(!!dxfCode && code!=0);
+          }while(dxfCode && code!=0);
 
           graphic->addHatching(patternScale,
                                patternName,
@@ -1975,10 +1984,12 @@ RFileDxf::readFromBuffer(bool add)
         }
 
       }
-    } while(!!dxfLine && dxfLine!="EOF");
+    } while(dxfLine && dxfLine!="EOF");
     
     graphic->terminateAction();
 
+    graphic->debugElements();
+
     ret=true;
   }
   else {
@@ -2166,8 +2177,9 @@ RFileDxf::save()
         //fprintf(fPointer, " 39\n%d\n",
         //                  lay->getWidth());
 
+		int colNum = graphic->colorToNumber(lay->getColor(), true);
         fprintf(fPointer, " 62\n%d\n",
-                          graphic->colorToNumber(lay->getColor()));
+                          (colNum==0 ? 7 : colNum));
         fprintf(fPointer, "  6\n%s\n",
                           graphic->styleToName(lay->getStyle()).latin1());
       }
@@ -2186,7 +2198,7 @@ RFileDxf::save()
     // ELEMENTS:
     //
     for(el=graphic->elementFirst(); el!=0; el=graphic->elementNext()) {
-      //if(el->getFlag(E_VISIBLE)) {   // Save elements on invisible layers too!!
+      //if(el->getFlag(E_VISIBLE)) {   // Save elements on invisible layers too
       if(el->getFlag(E_ACTIVE) && !el->getFlag(E_UNDO)) {
 
         statusPanel()->setProgress(graphic->elementAt(), 200);
@@ -2208,7 +2220,7 @@ RFileDxf::save()
             fprintf(fPointer, " 39\n%d\n",
                               el->getWidth());
             fprintf(fPointer, " 62\n%d\n",
-                              graphic->colorToNumber(el->getColor()));
+                              graphic->colorToNumber(el->getColor(), true));
             fflush( fPointer );
             break;
             
@@ -2230,7 +2242,7 @@ RFileDxf::save()
             fprintf(fPointer, " 39\n%d\n",
                               el->getWidth());
             fprintf(fPointer, " 62\n%d\n",
-                              graphic->colorToNumber(el->getColor()));
+                              graphic->colorToNumber(el->getColor(), true));
             fflush( fPointer );
             break;
             
@@ -2262,7 +2274,7 @@ RFileDxf::save()
             fprintf(fPointer, " 39\n%d\n",
                               el->getWidth());
             fprintf(fPointer, " 62\n%d\n",
-                              graphic->colorToNumber(el->getColor()));
+                              graphic->colorToNumber(el->getColor(), true));
             fflush( fPointer );
             break;
             
@@ -2282,7 +2294,7 @@ RFileDxf::save()
             fprintf(fPointer, " 39\n%d\n",
                               el->getWidth());
             fprintf(fPointer, " 62\n%d\n",
-                              graphic->colorToNumber(el->getColor()));
+                              graphic->colorToNumber(el->getColor(), true));
             fflush( fPointer );
             break;
             
@@ -2348,7 +2360,7 @@ RFileDxf::save()
                   fprintf(fPointer, " 39\n%d\n",
                                     el->getWidth());
                   fprintf(fPointer, " 62\n%d\n",
-                                    graphic->colorToNumber(el->getColor()));
+                                    graphic->colorToNumber(el->getColor(), true));
                 }
   
                 // Go to pos of next line:
@@ -2439,7 +2451,7 @@ RFileDxf::save()
                 fprintf(fPointer, " 70\n%d\n", 4);
               }
               else if(el->getFlag(E_ARROW)) {
-                fprintf(fPointer, " 70\n%d\n", 7);   // Not DXF compatible!!!
+                fprintf(fPointer, " 70\n%d\n", 7);   // Not DXF compatible!
               }
               else {
                 fprintf(fPointer, " 70\n%d\n", 1);
@@ -2478,7 +2490,7 @@ RFileDxf::save()
             fprintf(fPointer, " 39\n%d\n",
                               el->getWidth());
             fprintf(fPointer, " 62\n%d\n",
-                              graphic->colorToNumber(el->getColor()));
+                              graphic->colorToNumber(el->getColor(), true));
             fflush( fPointer );
             break;
 
@@ -2554,7 +2566,7 @@ RFileDxf::save()
             fprintf(fPointer, " 39\n%d\n",
                               el->getWidth());
             fprintf(fPointer, " 62\n%d\n",
-                              graphic->colorToNumber(el->getColor()));
+                              graphic->colorToNumber(el->getColor(), true));
             fflush( fPointer );
             break;
             
