@@ -25,7 +25,7 @@ class RGraphic;
 class RFileDxf : public RFileBase
 {
 public:
-  RFileDxf(const char* _name, RGraphic* _graphic);
+  RFileDxf(const QString& _name, RGraphic* _graphic);
   ~RFileDxf();
 
   bool load(bool add=false);
