@@ -25,7 +25,7 @@ class RGraphic;
 class RFilePlt : public RFileBase
 {
 public:
-  RFilePlt(const char* _name, RGraphic* _graphic);
+  RFilePlt(const QString& _name, RGraphic* _graphic);
   ~RFilePlt();
 
   bool load(bool add=false);
