@@ -18,20 +18,20 @@
 
 #include <qwidget.h>
 
-class RLabel;
+class QLabel;
 class QPixmap;
 
 class RIntro : public QWidget
 {
   Q_OBJECT
 public:
-  RIntro(const char* _version,
+  RIntro(const QString& _version,
          QWidget* _parent=0, 
          const char* _name=0);
   ~RIntro();
 
 private:
-  QCString    sVersion;
+  QString    sVersion;
   QPixmap*   pIntro;
 
 protected:
