@@ -15,6 +15,7 @@
 *****************************************************************************/
 
 #include "rlayer.h"
+#include "rcolor.h"
 
 // Constructor:
 //
@@ -22,7 +23,7 @@ RLayer::RLayer()
 {
   name="";
   number=-1;
-  color=Qt::black;
+  color=rBlack;
   width=0;
   style=Qt::SolidLine;
 }
