@@ -74,20 +74,20 @@ RSnap::~RSnap()
 //          false: no point to snap in mouse range
 //
 bool
-RSnap::snapPoint(float* _x, float* _y,
+RSnap::snapPoint(double* _x, double* _y,
                  bool _definitive,
                  RElement* _onlyElement,
                  bool _showPreview,
                  bool _calcDirection,
-                 float* _direction) 
+                 double* _direction) 
 {
   bool ret=false;
   
-  if(currentDoc()) {
+  if( currentDoc() && currentDoc()->isMouseInside() ) {
 
     // Coordinates set by keyboard:
     /*if(currentDoc()->keyCoordsEnabled()) {
-      float kx, ky;
+      double kx, ky;
       currentDoc()->getKeyCoords(&kx, &ky);
       if(_x) *_x=kx;
       if(_y) *_y=ky;
@@ -211,18 +211,41 @@ RSnap::snapPoint(float* _x, float* _y,
     if(_showPreview) {
       if(ret) {
         currentDoc()->drawMark(cx, cy);
-        //currentDoc()->drawPreviewElement();
-        char buf[128];
-        sprintf(buf, "Abs: X: %.4f / Y: %.4f\n"
+        QString buf;
+        /*sprintf(buf, "Abs: X: %.4f / Y: %.4f\n"
                      "Rel: X: %.4f / Y: %.4f\n",
                      cx, cy,
                      cx-currentDoc()->getRelZeroX(),
-                     cy-currentDoc()->getRelZeroY() );
+                     cy-currentDoc()->getRelZeroY() );*/
+        buf = "Abs: X: "
+            + mtFormatFloat( cx,
+                             currentDoc()->getDimensionExactness(),
+                             currentDoc()->getDimensionUnit(),
+                             currentDoc()->getDimensionFormat(),
+                             true )
+            + " / Y: "
+            + mtFormatFloat( cy,
+                             currentDoc()->getDimensionExactness(),
+                             currentDoc()->getDimensionUnit(),
+                             currentDoc()->getDimensionFormat(),
+                             true )
+            + "\nRel: X: "
+            + mtFormatFloat( cx-currentDoc()->getRelZeroX(),
+                             currentDoc()->getDimensionExactness(),
+                             currentDoc()->getDimensionUnit(),
+                             currentDoc()->getDimensionFormat(),
+                             true )
+            + " / Y: "
+            + mtFormatFloat( cy-currentDoc()->getRelZeroY(),
+                             currentDoc()->getDimensionExactness(),
+                             currentDoc()->getDimensionUnit(),
+                             currentDoc()->getDimensionFormat(),
+                             true );
+
         statusPanel()->setStatus(buf);
       }
       else {
         currentDoc()->delMark();
-        //currentDoc()->delPreviewElement();
       }
     }
   }
@@ -237,25 +260,16 @@ RSnap::snapPoint(float* _x, float* _y,
 void
 RSnap::stop() 
 {
-  RLOG("\nStop snapper");
-  
   if(currentDoc()) {
-    RLOG("\nDel Mark...");
     currentDoc()->delMark();
     cx = cy = DEF_AREAMAX;
     currentDoc()->delPreviewElement();
     currentDoc()->delPreview();
-    RLOG("\nReset Preview Element...");
     currentDoc()->resetPreviewElement();
-    RLOG("\nReset Highlight Element...");
     currentDoc()->resetHighlightElement();
-    RLOG("\nDel Highlight Element...");
     currentDoc()->delHighlightElement();
-    RLOG("\nSet First Element to zero...");
     firstElement=0;
   }
-  
-  RLOG("\nSnapper stopped");
 }
 
 
@@ -283,95 +297,61 @@ RSnap::snapFree()
 bool
 RSnap::snapGrid()
 {
-  double minDist=DEF_AREAMAX;
+  double minDist;
   double dist;
-  double startCX,           // Mousepointers is in this
-        stopCX,            // range of grid units
-        startCY,
-        stopCY;
-  double gpX;               // Grid point X
-  double gpY;               // Grid point Y
-  float  rmx;               // real mousepos X
-  float  rmy;               // real mousepos Y
+  double startC[2],           // Mousepointers is in this
+         stopC[2];            // range of grid units
+  double gp[2];               // Grid point X
+  double rm[2];               // real mousepos X
+  int    i;
 
-  currentDoc()->getRealMousePos(&rmx, &rmy);
+  currentDoc()->getRealMousePos(&rm[0], &rm[1]);
 
   currentDoc()->enableMark(true);
 
   // enlarge grid to reasonable size:
   //
-  double mg = currentDoc()->getCurrentGridWidth();
-  /*
-  double mg = RCONFIG->getSettingDouble("CAD:GridWidth");
-  if(mg<0.00001) mg = 0.00001;
-
-  while(mg*currentDoc()->getZoom()<6.0 && mg<RIni::getRIni()->getGridWidth()*100000.0) { mg*=10.0; }
-  */
+  double mg[2];
+  for( i=0; i<=1; i++ ) {
+    mg[i] = currentDoc()->getCurrentGridWidth( i );
+  }
 
   // Get the range, where the mousepointer is (in factor 100 of grid pieces)
   //
-  if(rmx>=0.0) {
-    startCX = 0.0;
-    for(stopCX=0.0; stopCX<=DEF_AREAMAX; stopCX+=mg*100.0) {
-      if(stopCX>rmx) break;
-      startCX = stopCX;
+  for( i=0; i<=1; ++i ) {
+    if(rm[i]>=0.0) {
+      startC[i] = 0.0;
+      for(stopC[i]=0.0; stopC[i]<=DEF_AREAMAX; stopC[i]+=mg[i]*100.0) {
+        if(stopC[i]>rm[i]) break;
+        startC[i] = stopC[i];
+      }
     }
-    //startCX = 0.0;
-  }
-  else {
-    stopCX = 0.0;
-    for(startCX=0.0; startCX>=DEF_AREAMIN; startCX-=mg*100.0) {
-      if(startCX<rmx) break;
-      stopCX = startCX;
+    else {
+      stopC[i] = 0.0;
+      for(startC[i]=0.0; startC[i]>=DEF_AREAMIN; startC[i]-=mg[i]*100.0) {
+        if(startC[i]<rm[i]) break;
+        stopC[i] = startC[i];
+      }
     }
-    //stopCX = 0.0;
   }
 
-  if(rmy>=0.0) {
-    startCY = 0.0;
-    for(stopCY=0.0; stopCY<=DEF_AREAMAX; stopCY+=mg*100.0) {
-      if(stopCY>rmy) break;
-      startCY = stopCY;
-    }
-    //startCY = 0.0;
-  }
-  else {
-    stopCY = 0.0;
-    for(startCY=0.0; startCY>=DEF_AREAMIN; startCY-=mg*100.0) {
-      if(startCY<rmy) break;
-      stopCY = startCY;
-    }
-    //stopCY = 0.0;
-  }
-
-  // Get the snapped x-coordinate:
+  // Get the snapped coordinate:
   //
-  for(gpX=startCX; gpX<=stopCX+mg; gpX+=mg) {
-    // Check grid point:
-    //
-    dist = mtGetDistance(rmx, rmy, gpX, startCY);
-    if(dist<minDist) {
-      minDist = dist;
-      cx = gpX;
-    }
-    else if(minDist<DEF_AREAMAX) {
-      break;
-    }
-  }
-
-  // Get the snapped y-coordinate:
-  //
-  minDist = DEF_AREAMAX;
-  for(gpY=startCY; gpY<=stopCY+mg; gpY+=mg) {
-    // Check grid point:
-    //
-    dist = mtGetDistance(rmx, rmy, gpX, gpY);
-    if(dist<minDist) {
-      minDist = dist;
-      cy = gpY;
-    }
-    else if(minDist<DEF_AREAMAX) {
-      break;
+  for( i=0; i<=1; ++i ) {
+    minDist=DEF_AREAMAX;
+    for(gp[i]=startC[i]; gp[i]<=stopC[i]+mg[i]; gp[i]+=mg[i]) {
+      // Check grid point:
+      //
+      if(i==0) dist = mtGetDistance(rm[0], rm[1], gp[0], startC[1]);
+      else     dist = mtGetDistance(rm[0], rm[1], gp[0], gp[1]);
+      if(dist<minDist) {
+        minDist = dist;
+        if(i==0) cx = gp[0];
+        else     cy = gp[1];
+      }
+      else if(minDist<DEF_AREAMAX) {
+        break;
+      }
     }
   }
 
@@ -388,12 +368,12 @@ RSnap::snapGrid()
 bool
 RSnap::snapEndpoints()
 {
-  float rmx, rmy;  // Real mouse pos
+  double rmx, rmy;  // Real mouse pos
   currentDoc()->getRealMousePos(&rmx, &rmy);
 
-  //float minDist=DEF_AREAMAX;  // minimum measured distance
-  float minDist=snapRange;    // minimum measured distance
-  float dist;                 // measured distance
+  //double minDist=DEF_AREAMAX;  // minimum measured distance
+  double minDist=snapRange;    // minimum measured distance
+  double dist;                 // measured distance
   RElement* el;               // element ptr (walks through elements)
   RElement* snappedElement=0;    // snapped element
   bool startPoint=true;       // snapped to startpoint?
@@ -463,12 +443,12 @@ RSnap::snapEndpoints()
 bool
 RSnap::snapCenters()
 {
-  float rmx, rmy;  // Real mouse pos
+  double rmx, rmy;  // Real mouse pos
   currentDoc()->getRealMousePos(&rmx, &rmy);
 
-  //float minDist=DEF_AREAMAX;  // minimum measured distance
-  float minDist=snapRange;    // minimum measured distance
-  float dist;                 // measured distance
+  //double minDist=DEF_AREAMAX;  // minimum measured distance
+  double minDist=snapRange;    // minimum measured distance
+  double dist;                 // measured distance
   RElement* el;               // element ptr (walks through elements)
   RElement* snappedElement=0;    // snapped element
   bool found=false;           // snapped to point?
@@ -514,12 +494,12 @@ RSnap::snapCenters()
 bool
 RSnap::snapMiddles()
 {
-  float rmx, rmy;  // Real mouse pos
+  double rmx, rmy;  // Real mouse pos
   currentDoc()->getRealMousePos(&rmx, &rmy);
 
-  //float minDist=DEF_AREAMAX;  // minimum measured distance
-  float minDist=snapRange;    // minimum measured distance
-  float dist;                 // measured distance
+  //double minDist=DEF_AREAMAX;  // minimum measured distance
+  double minDist=snapRange;    // minimum measured distance
+  double dist;                 // measured distance
   RElement* el;               // element ptr (walks through elements)
   RElement* snappedElement=0;    // snapped element
   bool found=false;           // snapped to point?
@@ -565,19 +545,19 @@ RSnap::snapMiddles()
 bool
 RSnap::snapAutoInter()
 {
-  float rmx, rmy;  // Real mouse pos
+  double rmx, rmy;  // Real mouse pos
   currentDoc()->getRealMousePos(&rmx, &rmy);
   
-  //float minDist=DEF_AREAMAX;
-  float minDist=snapRange;    // minimum measured distance
-  float dist;
-  float lb, bb, rb, tb;    // Element borders
+  //double minDist=DEF_AREAMAX;
+  double minDist=snapRange;    // minimum measured distance
+  double dist;
+  double lb, bb, rb, tb;    // Element borders
   RElement* el1;           // element ptr (walks through elements)
   RElement* el2;           // element ptr (walks through elements)
   //RElement* elBak;         // Backup element pos for two loops
   bool  found=false;       // There was a point in catch range
-  float ix1, iy1;          // Intersection result 1
-  float ix2, iy2;          // Intersection result 2
+  double ix1, iy1;          // Intersection result 1
+  double ix2, iy2;          // Intersection result 2
   bool  ires1, ires2;      // Tells if there are results
 
   currentDoc()->enableMark(true);
@@ -674,7 +654,7 @@ bool
 RSnap::snapManInter(bool _definitive)
 {
   bool ret=true;   // return value
-  float rmx, rmy;  // Real mouse pos
+  double rmx, rmy;  // Real mouse pos
   currentDoc()->getRealMousePos(&rmx, &rmy);
 
   cx = DEF_AREAMAX;
@@ -701,7 +681,7 @@ RSnap::snapManInter(bool _definitive)
     else {
       currentDoc()->setHighlightFilter(T_LONG, firstElement);
       bool ires1, ires2;
-      float ix1, iy1, ix2, iy2;
+      double ix1, iy1, ix2, iy2;
       ires1=false;
       ires2=false;
       ix1=iy1=ix2=iy2=DEF_AREAMAX;
@@ -762,12 +742,12 @@ RSnap::snapManInter(bool _definitive)
 bool
 RSnap::snapDist()
 {
-  float rmx, rmy;  // Real mouse pos
+  double rmx, rmy;  // Real mouse pos
   currentDoc()->getRealMousePos(&rmx, &rmy);
 
-  //float minDist=DEF_AREAMAX;  // minimum measured distance
-  float minDist=snapRange;    // minimum measured distance
-  float dist;                 // measured distance
+  //double minDist=DEF_AREAMAX;  // minimum measured distance
+  double minDist=snapRange;    // minimum measured distance
+  double dist;                 // measured distance
   RElement* el;               // element ptr (walks through elements)
   RElement* snappedElement=0;    // snapped element
   bool found=false;           // There was a point in range
@@ -841,12 +821,12 @@ RSnap::snapDist()
 bool
 RSnap::snapOnElement()
 {
-  float rmx, rmy;  // Real mouse pos
+  double rmx, rmy;  // Real mouse pos
   currentDoc()->getRealMousePos(&rmx, &rmy);
 
-  //float minDist=DEF_AREAMAX;  // minimum measured distance
-  float minDist=snapRange;    // minimum measured distance
-  float dist;                 // measured distance
+  //double minDist=DEF_AREAMAX;  // minimum measured distance
+  double minDist=snapRange;    // minimum measured distance
+  double dist;                 // measured distance
   RElement* el;               // element ptr (walks through elements)
   RElement* snappedElement=0; // snapped element
   bool found=false;           // snapped to point?
@@ -897,17 +877,17 @@ RSnap::snapElement(bool _show,
                    int _types,
                    RElement* _exception)
 {
-  float rmx, rmy;  // Real mouse pos
+  double rmx, rmy;  // Real mouse pos
   currentDoc()->getRealMousePos(&rmx, &rmy);
 
   recalculateSnapRange();
   
   bool found=false;    // element found
-  float minDist=snapRange;    // minimum measured distance
-  float dist;
+  double minDist=snapRange;    // minimum measured distance
+  double dist;
   RElement* el;        // element ptr (walks through elements)
   
-  cEl=0;
+  cEl=0;               // reset snapped element
 
   //int omx=np->GetCadWin()->GetMX();
   //int omy=np->GetCadWin()->GetMY();
@@ -976,6 +956,11 @@ RSnap::recalculateSnapRange()
 
 
 
+
+
+
+
+
 
 
 
