@@ -121,7 +121,7 @@ RToolButton::drawButton( QPainter * p )
                            colorGroup().background() );
     } 
     else {
-      p->setPen( black );
+      p->setPen( rBlack );
       p->drawRect( 3, 3, width()-6, height()-6 );
     }
   }
